@@ -1,19 +1,8 @@
 /*
-  Copyright (C) 2017-2020 Laurent Montel <montel@kde.org>
-  Copyright (c) 2017 David Faure <faure@kde.org>
+  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017 David Faure <faure@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "jobtrackermodeltest.h"
@@ -70,7 +59,7 @@ void JobTrackerModelTest::shouldDisplayOneJob()
     QSignalSpy rowATBISpy(&model, &QAbstractItemModel::rowsAboutToBeInserted);
     QSignalSpy rowInsertedSpy(&model, &QAbstractItemModel::rowsInserted);
     connect(&model, &QAbstractItemModel::rowsAboutToBeInserted,
-            this, [&](const QModelIndex & parent) {
+            this, [&](const QModelIndex &parent) {
         // rowsAboutToBeInserted is supposed to be emitted before the insert
         if (!parent.isValid()) {
             QCOMPARE(model.rowCount(), 0);
@@ -79,7 +68,7 @@ void JobTrackerModelTest::shouldDisplayOneJob()
         }
     });
     connect(&model, &QAbstractItemModel::rowsInserted,
-            this, [&](const QModelIndex & parent) {
+            this, [&](const QModelIndex &parent) {
         if (!parent.isValid()) {
             QCOMPARE(model.rowCount(), 1);
             QVERIFY(model.index(0, 0).isValid());
