@@ -1,20 +1,7 @@
 /*
-    Copyright (c) 2009 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2009 Volker Krause <vkrause@kde.org>
 
-    This library is free software; you can redistribute it and/or modify it
-    under the terms of the GNU Library General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or (at your
-    option) any later version.
-
-    This library is distributed in the hope that it will be useful, but WITHOUT
-    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-    License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to the
-    Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-    02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "dbconsole.h"
@@ -37,7 +24,6 @@
 
 DbConsole::DbConsole(QWidget *parent)
     : QWidget(parent)
-    , mTabCounter(0)
 {
     auto l = new QVBoxLayout(this);
 
@@ -45,9 +31,9 @@ DbConsole::DbConsole(QWidget *parent)
     mTabWidget->tabBar()->setTabsClosable(true);
     connect(mTabWidget->tabBar(), &QTabBar::tabCloseRequested,
             mTabWidget, [this](int index) {
-                mTabWidget->removeTab(index);
-                saveQueries();
-            });
+        mTabWidget->removeTab(index);
+        saveQueries();
+    });
     l->addWidget(mTabWidget);
 
     auto addTabButton = new QPushButton(QIcon::fromTheme(QStringLiteral("tab-new")), QString());
@@ -79,7 +65,7 @@ void DbConsole::saveQueries()
     QStringList queries;
     queries.reserve(mTabWidget->count());
     for (int i = 0; i < mTabWidget->count(); ++i) {
-        auto tab = qobject_cast<DbConsoleTab*>(mTabWidget->widget(i));
+        auto tab = qobject_cast<DbConsoleTab *>(mTabWidget->widget(i));
         queries << tab->query();
     }
     KSharedConfig::openConfig()->group("DBConsole").writeEntry("queryTexts", queries);
@@ -94,10 +80,10 @@ DbConsoleTab *DbConsole::addTab()
     return tab;
 }
 
-DbConsoleTab::DbConsoleTab(int index, QWidget *parent) :
-    QWidget(parent),
-    mQueryModel(nullptr),
-    mIndex(index)
+DbConsoleTab::DbConsoleTab(int index, QWidget *parent)
+    : QWidget(parent)
+    , mQueryModel(nullptr)
+    , mIndex(index)
 {
     ui.setupUi(this);
 
@@ -153,4 +139,3 @@ void DbConsoleTab::copyCell()
     QString text = index.data(Qt::DisplayRole).toString();
     QApplication::clipboard()->setText(text);
 }
-
