@@ -1,22 +1,9 @@
 /*
     This file is part of Akonadi.
 
-    Copyright (c) 2012 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2012 Volker Krause <vkrause@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-    USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "instanceselector.h"
@@ -37,17 +24,16 @@
 #include <QVBoxLayout>
 
 InstanceSelector::InstanceSelector(const QString &remoteHost, QWidget *parent, Qt::WindowFlags flags)
-    : QDialog(parent, flags),
-      ui(new Ui::InstanceSelector),
-      m_remoteHost(remoteHost),
-      mWindow(nullptr)
+    : QDialog(parent, flags)
+    , ui(new Ui::InstanceSelector)
+    , m_remoteHost(remoteHost)
 {
-    QWidget *mainWidget = new QWidget(this);
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    auto *mainWidget = new QWidget(this);
+    auto *mainLayout = new QVBoxLayout(this);
     mainLayout->addWidget(mainWidget);
     ui->setupUi(mainWidget);
 
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Close, this);
+    auto *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Close, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -66,9 +52,9 @@ InstanceSelector::InstanceSelector(const QString &remoteHost, QWidget *parent, Q
         }
         slotAccept();
     } else {
-        QStandardItemModel *model = new QStandardItemModel(this);
+        auto *model = new QStandardItemModel(this);
         for (const QString &inst : insts) {
-            QStandardItem *item = new QStandardItem;
+            auto *item = new QStandardItem;
             item->setText(inst.isEmpty() ? QStringLiteral("<global>") : inst);
             item->setData(inst, Qt::UserRole);
             model->appendRow(item);
@@ -97,7 +83,7 @@ void InstanceSelector::slotAccept()
 
     qputenv("AKONADI_INSTANCE", m_instance.toUtf8());
     Akonadi::Instance::setIdentifier(m_instance);
-    MainWindow *mWindow = new MainWindow;
+    auto *mWindow = new MainWindow;
     if (!m_remoteHost.isEmpty()) {
         mWindow->setWindowTitle(QStringLiteral("Remote Akonadi Console (%1)").arg(m_remoteHost));
     } else if (!m_instance.isEmpty()) {
