@@ -1,22 +1,9 @@
 /*
     This file is part of Akonadi.
 
-    Copyright (c) 2009 Till Adam <adam@kde.org>
+    SPDX-FileCopyrightText: 2009 Till Adam <adam@kde.org>
 
-    This program is free software; you can redistribute it and/or modify
-    it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
-    USA.
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "jobtrackerwidget.h"
@@ -28,7 +15,6 @@
 
 #include <AkonadiWidgets/controlgui.h>
 
-
 #include <QTreeView>
 #include <QHeaderView>
 #include <QVBoxLayout>
@@ -49,14 +35,14 @@ public:
 };
 
 JobTrackerWidget::JobTrackerWidget(const char *name, QWidget *parent, const QString &checkboxText)
-    : QWidget(parent),
-      d(new Private)
+    : QWidget(parent)
+    , d(new Private)
 {
     d->model = new JobTrackerModel(name, this);
 
-    QVBoxLayout *layout = new QVBoxLayout(this);
+    auto *layout = new QVBoxLayout(this);
 
-    QCheckBox *enableCB = new QCheckBox(this);
+    auto *enableCB = new QCheckBox(this);
     enableCB->setText(checkboxText);
     connect(enableCB, &QAbstractButton::toggled, d->model, &JobTrackerModel::setEnabled);
     layout->addWidget(enableCB);
@@ -81,7 +67,7 @@ JobTrackerWidget::JobTrackerWidget(const char *name, QWidget *parent, const QStr
     layout->addWidget(d->tv);
     d->model->setEnabled(false);   // since it can be slow, default to off
 
-    QHBoxLayout *layout2 = new QHBoxLayout;
+    auto *layout2 = new QHBoxLayout;
     QPushButton *button = new QPushButton(QStringLiteral("Save to file..."), this);
     connect(button, &QAbstractButton::clicked,
             this, &JobTrackerWidget::slotSaveToFile);
@@ -99,8 +85,8 @@ JobTrackerWidget::~JobTrackerWidget()
 
 void JobTrackerWidget::selectOnlyErrorChanged(bool state)
 {
-     d->filterProxyModel->setShowOnlyFailed(state);
-     d->tv->expandAll();
+    d->filterProxyModel->setShowOnlyFailed(state);
+    d->tv->expandAll();
 }
 
 void JobTrackerWidget::searchColumnChanged(int index)
@@ -115,7 +101,7 @@ void JobTrackerWidget::textFilterChanged(const QString &str)
     d->tv->expandAll();
 }
 
-void JobTrackerWidget::contextMenu(const QPoint &/*pos*/)
+void JobTrackerWidget::contextMenu(const QPoint & /*pos*/)
 {
     QMenu menu;
     menu.addAction(QStringLiteral("Clear View"), d->model, &JobTrackerModel::resetTracker);
