@@ -1,19 +1,7 @@
 /*
- * Copyright (C) 2013  Daniel Vrátil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2013 Daniel Vrátil <dvratil@redhat.com>
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
+ * SPDX-License-Identifier: GPL-2.0-or-later
  *
  */
 
@@ -24,8 +12,7 @@
 #include <AkonadiCore/NotificationSubscriber>
 #include "libakonadiconsole_export.h"
 
-namespace Akonadi
-{
+namespace Akonadi {
 class Monitor;
 }
 
@@ -37,7 +24,7 @@ public:
     enum Roles {
         SubscriberRole = Qt::UserRole
     };
-        
+
     explicit MonitorsModel(QObject *parent = nullptr);
     virtual ~MonitorsModel();
 
@@ -61,7 +48,7 @@ private Q_SLOTS:
 
 private:
     QList<QByteArray> mSessions;
-    QHash<QByteArray /* session */, QVector<Akonadi::NotificationSubscriber>> mData;
+    QHash<QByteArray /* session */, QVector<Akonadi::NotificationSubscriber> > mData;
     Akonadi::Monitor *mMonitor;
 };
 
